tar_test("reporter abstract class", {
  skip_cran()
  x <- reporter_class$new()
  expect_null(x$report_start())
  expect_message(x$report_error("x"), class = "tar_condition_run")
  expect_null(x$report_completed())
  expect_null(x$report_skipped())
  expect_null(x$report_errored())
  expect_null(x$report_canceled())
  expect_null(x$report_outdated(NULL))
  expect_null(x$report_outdated_end(NULL))
  expect_null(x$report_workspace(NULL))
  expect_null(x$report_workspace_upload(NULL))
  expect_null(x$report_retry())
  expect_null(x$validate())
})
